SchemaSpy - Table gnss_data.public.earthquakes

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.earthquakes | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
date | timestamp | 29,6 |  |  |  |  |  |
lat | numeric | 131089 |  |  |  |  |  |
lon | numeric | 131089 |  |  |  |  |  |
depth | numeric | 131089 | √ |  | null |  |  |
mag | numeric | 131089 | √ |  | null |  |  |
Table contained 3,263 rows at Fri Jul 28 14:55 EDT 2017